@@ -111,8 +111,10 @@ public:
 	bool canDisconnect() const;
 
 	// Edit predicates.
-	bool canRenameItem() const;
 	bool canSearchItem() const;
+	bool canRenameItem() const;
+
+	bool canArrangeNodes() const;
 
 	// Zooming methods.
 	void setZoom(qreal zoom);
@@ -121,6 +123,8 @@ public:
 	void setZoomRange(bool zoomrange);
 	bool isZoomRange() const;
 
+	void centerView(bool showSelected);
+
 	// Clean-up all un-marked nodes...
 	void resetNodes(uint node_type);
 	void clearNodes(uint node_type);
@@ -247,8 +251,10 @@ public slots:
 	void selectInvert();
 
 	// Edit actions.
-	void renameItem();
 	void searchItem();
+	void renameItem();
+
+	void arrangeNodes();
 
 	// Discrete zooming actions.
 	void zoomIn();
