@@ -1,7 +1,7 @@
 // qpwgraph_node.cpp
 //
 /****************************************************************************
-   Copyright (C) 2021-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2021-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -42,7 +42,8 @@
 qpwgraph_node::qpwgraph_node (
 	uint id, const QString& name, qpwgraph_item::Mode mode, uint type )
 	: qpwgraph_item(nullptr),
-		m_id(id), m_name(name), m_mode(mode), m_type(type)
+		m_id(id), m_name(name), m_mode(mode), m_type(type),
+		m_num(0), m_name_ex(false)
 {
 	QGraphicsPathItem::setZValue(0.0);
 
@@ -113,9 +114,16 @@ void qpwgraph_node::setNodeName ( const QString& name )
 }
 
 
-const QString& qpwgraph_node::nodeName (void) const
+QString qpwgraph_node::nodeName (void) const
 {
-	return m_name;
+	QString name = m_name;
+
+	if (m_num > 0) {
+		name += '-';
+		name += QString::number(m_num);
+	}
+
+	return name;
 }
 
 
@@ -157,6 +165,20 @@ const QIcon& qpwgraph_node::nodeIcon (void) const
 }
 
 
+void qpwgraph_node::setNodeNum ( uint num )
+{
+	m_num = num;
+
+	setNodeTitle(QString()); // reset title.
+}
+
+
+uint qpwgraph_node::nodeNum (void) const
+{
+	return m_num;
+}
+
+
 void qpwgraph_node::setNodeLabel ( const QString& label )
 {
 	m_label = label;
@@ -173,16 +195,16 @@ const QString& qpwgraph_node::nodeLabel (void) const
 
 QString qpwgraph_node::nodeNameLabel (void) const
 {
-	QString label = m_name;
+	QString name_label = nodeName();
 
 	if (!m_label.isEmpty()) {
-		label += ' ';
-		label += '[';
-		label += m_label;
-		label += ']';
+		name_label += ' ';
+		name_label += '[';
+		name_label += m_label;
+		name_label += ']';
 	}
 
-	return label;
+	return name_label;
 }
 
 
@@ -224,6 +246,24 @@ const QString& qpwgraph_node::nodePrefix (void) const
 }
 
 
+void qpwgraph_node::setNodeNameEx ( bool name_ex )
+{
+	m_name_ex = name_ex;
+}
+
+
+bool qpwgraph_node::isNodeNameEx (void) const
+{
+	return m_name_ex;
+}
+
+
+QString qpwgraph_node::nodeNameEx (void) const
+{
+	return (m_name_ex ? m_name : nodeName());
+}
+
+
 // Port-list methods.
 qpwgraph_port *qpwgraph_node::addPort (
 	uint id, const QString& name, qpwgraph_item::Mode mode, int type )
